@@ -46,6 +46,8 @@ from .responses import (Comment, CommentList, CreateFileUploadResponse, DeletedN
 
 # constants for uploads 
 CHUNK_SIZE = 33554432
+#min chunk size S3
+MIN_CHUNK_SIZE = 5242880
 MAX_CHUNKS = 9999
 POLL_WAIT = 0.1
 
@@ -184,11 +186,11 @@ class DRACOONNodes:
             parent_path = '/'.join(path.split('/')[:-1])
             depth = len(path.split('/')[:-1])
 
-        filter_str = f'&filter=parentPath:eq:{parent_path}/'
+        filter_str = f'parentPath:eq:{parent_path}/'
 
-        
         if filter: filter_str += f'|{filter}'
         
+        filter_str = urllib.parse.quote(filter_str)
         last_node = urllib.parse.quote(last_node)
 
         if not await self.dracoon.test_connection() and self.dracoon.connection:
@@ -197,7 +199,7 @@ class DRACOONNodes:
         if self.raise_on_err:
             raise_on_err = True
 
-        api_url = self.api_url + f'/search?search_string={last_node}{filter_str}&depth_level={str(depth)}'
+        api_url = self.api_url + f'/search?search_string={last_node}&filter={filter_str}&depth_level={str(depth)}'
 
         try:
             res = await self.dracoon.http.get(url=api_url)
@@ -906,6 +908,8 @@ class DRACOONNodes:
 
         if self.raise_on_err:
             raise_on_err = True
+            
+        if filter: filter = urllib.parse.quote(filter)
 
         api_url = self.api_url + \
             f'/?offset={offset}&parent_id={str(parent_id)}&room_manager={str(room_manager).lower()}'
@@ -1113,6 +1117,8 @@ class DRACOONNodes:
 
         if self.raise_on_err:
             raise_on_err = True
+            
+        if filter: filter = urllib.parse.quote(filter)
 
         api_url = self.api_url + \
             f'/{str(parent_id)}/deleted_nodes/?offset={offset}'
@@ -1837,6 +1843,8 @@ class DRACOONNodes:
 
         api_url = self.api_url + \
             f'/rooms/{str(room_id)}/groups/?offset={str(offset)}'
+        
+        if filter: filter = urllib.parse.quote(filter)
 
         if filter != None:
             api_url += f'&filter={filter}'
@@ -1923,6 +1931,8 @@ class DRACOONNodes:
 
         if self.raise_on_err:
             raise_on_err = True
+            
+        if filter: filter = urllib.parse.quote(filter)
 
         api_url = self.api_url + \
             f'/rooms/{str(room_id)}/users/?offset={str(offset)}'
@@ -2013,6 +2023,8 @@ class DRACOONNodes:
 
         if self.raise_on_err:
             raise_on_err = True
+        
+        if filter: filter = urllib.parse.quote(filter)
 
         api_url = self.api_url + \
             f'/rooms/{str(node_id)}/webhooks/?offset={str(offset)}'
@@ -2074,6 +2086,8 @@ class DRACOONNodes:
 
         if self.raise_on_err:
             raise_on_err = True
+            
+        if filter: filter = urllib.parse.quote(filter)
 
         api_url = self.api_url + f'/rooms/{room_id}/events/?offset={str(offset)}'
 
@@ -2109,6 +2123,8 @@ class DRACOONNodes:
             raise_on_err = True
 
         api_url = self.api_url + f'/rooms/pending/?offset={str(offset)}'
+        
+        if filter: filter = urllib.parse.quote(filter)
 
         if filter != None:
             api_url += f'&filter={filter}'
@@ -2169,6 +2185,7 @@ class DRACOONNodes:
             raise_on_err = True
             
         search = urllib.parse.quote(search)
+        if filter: filter = urllib.parse.quote(filter)
 
         api_url = self.api_url + \
             f'/search/?search_string={search}&offset={str(offset)}&parent_id={str(parent_id)}&depth_level={depth_level}'
